Module reader

Module reader 

A reader default uses system endianness If you will use another endianness,use set_endian. 0.0.10 StreamReader enable for wasm32

Structs

BytesReader
BytesReader from creating Slice &[u8] or Vec<u8>, no use Read trait
StreamReader

Traits

BinaryReader
0.0.11 Some functions have been changed to be written in this trait.