A reader default uses system endianness If you will use another endianness,use set_endian. 0.0.10 StreamReader enable for wasm32
Structs
- Bytes
Reader - BytesReader from creating Slice
&[u8]orVec<u8>, no use Read trait - Stream
Reader
Traits
- Binary
Reader - 0.0.11 Some functions have been changed to be written in this trait.